Developers

Référence API pour les développeurs

An API key is required for requests to be processed by the system. Once a user registers, an API key is automatically generated for this user.

Mulai

Une clé API est requise pour que les demandes soient traitées par le système. Une fois qu'un utilisateur s'inscrit, une clé API est automatiquement générée pour cet utilisateur. La clé API doit être envoyée avec chaque requête (voir l'exemple complet ci-dessous). Si la clé API n'est pas envoyée ou a expiré, il y aura une erreur. Assurez-vous de garder votre clé API secrète pour éviter les abus.

Otentikasi

Pour vous authentifier auprès du système API, vous devez envoyer votre clé API en tant que jeton d'autorisation avec chaque demande. Vous pouvez voir un exemple de code ci-dessous.

curl --location --request POST 'https://urlkai.com/api/account' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \ 

Limite de débit

Notre API dispose d'un limiteur de débit pour se protéger contre les pics de demandes afin de maximiser sa stabilité. Notre limiteur de débit est actuellement limité à 30 requêtes par 1 minute. Harap dicatat bahwa tarif dapat berubah sesuai dengan paket yang berlangganan.

Plusieurs en-têtes seront envoyés avec la réponse et ceux-ci peuvent être examinés pour déterminer diverses informations sur la demande.

X-RateLimit-Limit: 30X-RateLimit-Remaining: 29X-RateLimit-Reset: TIMESTAMP

Gestion des réponses

Toutes les réponses de l'API sont renvoyées au format JSON par défaut. Pour convertir cela en données utilisables, la fonction appropriée devra être utilisée en fonction de la langue. En PHP, la fonction json_decode() peut être utilisée pour convertir les données en objet (par défaut) ou en tableau (définissez le deuxième paramètre sur true). Il est très important de vérifier la clé d'erreur car elle indique s'il y a eu une erreur ou non. Vous pouvez également vérifier le code d'en-tête.

{
    "error": 1,
    "message": "An error occurred"
}

Kampanye

Daftar Kampanye

DAPAT https://urlkai.com/api/campaigns?limit=2&page=1

Untuk mendapatkan kampanye melalui API, Anda dapat menggunakan endpoint ini. Anda juga dapat memfilter data (Lihat tabel untuk info selengkapnya).

Paramètre La deskripsi
batas (opsional) Hasil data per halaman
halaman (opsional) Permintaan halaman saat ini
curl --location --request GET 'https://urlkai.com/api/campaigns?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Une clé API est requise pour les demandes à traiter par le système. Une fois qu'un utilisateur s'enregistre, une clé API est générée automatiquement pour cet utilisateur. La clé API doit être envoyée avec chaque requête via le paramètre clé (voir l'exemple complet ci-dessous). Si la clé API n'est pas envoyée ou a expiré, une erreur se produit. Assurez-vous de garder votre clé secrète de l'API pour éviter tout abus.

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "campaigns": [
            {
                "id": 1,
                "name": "Sample Campaign",
                "public": false,
                "rotator": false,
                "list": "https:\/\/domain.com\/u\/admin\/list-1"
            },
            {
                "id": 2,
                "domain": "Facebook Campaign",
                "public": true,
                "rotator": "https:\/\/domain.com\/r\/test",
                "list": "https:\/\/domain.com\/u\/admin\/test-2"
            }
        ]
    }
}

Créer une campagne

TIANG https://urlkai.com/api/campaign/add

Kampanye dapat ditambahkan menggunakan titik akhir ini.

Paramètre La deskripsi
Nama (opsional) Nama kampanye
Slug (opsional) Siput Rotator
umum (opsional) Akses
curl --location --request POST 'https://urlkai.com/api/campaign/add' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "name": "New Campaign",
    "slug": "new-campaign",
    "public": true
}'

Une clé API est requise pour les demandes à traiter par le système. Une fois qu'un utilisateur s'enregistre, une clé API est générée automatiquement pour cet utilisateur. La clé API doit être envoyée avec chaque requête via le paramètre clé (voir l'exemple complet ci-dessous). Si la clé API n'est pas envoyée ou a expiré, une erreur se produit. Assurez-vous de garder votre clé secrète de l'API pour éviter tout abus.

{
    "error": 0,
    "id": 3,
    "domain": "New Campaign",
    "public": true,
    "rotator": "https:\/\/domain.com\/r\/new-campaign",
    "list": "https:\/\/domain.com\/u\/admin\/new-campaign-3"
}
TIANG https://urlkai.com/api/campaign/:campaignid/assign/:linkid

Link pendek dapat ditetapkan ke kampanye menggunakan endpoint ini. Titik akhir memerlukan ID kampanye dan ID tautan pendek.

curl --location --request POST 'https://urlkai.com/api/campaign/:campaignid/assign/:linkid' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Une clé API est requise pour les demandes à traiter par le système. Une fois qu'un utilisateur s'enregistre, une clé API est générée automatiquement pour cet utilisateur. La clé API doit être envoyée avec chaque requête via le paramètre clé (voir l'exemple complet ci-dessous). Si la clé API n'est pas envoyée ou a expiré, une erreur se produit. Assurez-vous de garder votre clé secrète de l'API pour éviter tout abus.

{
    "error": 0,
    "message": "Link successfully added to the campaign."
}

Mettre à jour la campagne

MELETAKKAN https://urlkai.com/api/campaign/:id/update

Untuk memperbarui kampanye, Anda harus mengirim data yang valid dalam JSON melalui permintaan PUT. Data harus dikirim sebagai isi mentah permintaan Anda seperti yang ditunjukkan di bawah ini. Contoh di bawah ini menunjukkan semua parameter yang dapat Anda kirim tetapi Anda tidak diharuskan untuk mengirim semua (Lihat tabel untuk info selengkapnya).

Paramètre La deskripsi
Nama (wajib) Nama kampanye
Slug (opsional) Siput Rotator
umum (opsional) Akses
curl --location --request PUT 'https://urlkai.com/api/campaign/:id/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "name": "Twitter Campaign",
    "slug": "twitter-campaign",
    "public": true
}'

Une clé API est requise pour les demandes à traiter par le système. Une fois qu'un utilisateur s'enregistre, une clé API est générée automatiquement pour cet utilisateur. La clé API doit être envoyée avec chaque requête via le paramètre clé (voir l'exemple complet ci-dessous). Si la clé API n'est pas envoyée ou a expiré, une erreur se produit. Assurez-vous de garder votre clé secrète de l'API pour éviter tout abus.

{
    "error": 0,
    "id": 3,
    "domain": "Twitter Campaign",
    "public": true,
    "rotator": "https:\/\/domain.com\/r\/twitter-campaign",
    "list": "https:\/\/domain.com\/u\/admin\/twitter-campaign-3"
}

Hapus Kampanye

MENGHAPUS https://urlkai.com/api/campaign/:id/delete

Untuk menghapus kampanye, Anda harus mengirim permintaan DELETE.

curl --location --request DELETE 'https://urlkai.com/api/campaign/:id/delete' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Une clé API est requise pour les demandes à traiter par le système. Une fois qu'un utilisateur s'enregistre, une clé API est générée automatiquement pour cet utilisateur. La clé API doit être envoyée avec chaque requête via le paramètre clé (voir l'exemple complet ci-dessous). Si la clé API n'est pas envoyée ou a expiré, une erreur se produit. Assurez-vous de garder votre clé secrète de l'API pour éviter tout abus.

{
    "error": 0,
    "message": "Campaign has been deleted successfully."
}

Daftar Saluran

DAPAT https://urlkai.com/api/channels?limit=2&page=1

Untuk mendapatkan saluran Anda melalui API, Anda dapat menggunakan titik akhir ini. Anda juga dapat memfilter data (Lihat tabel untuk info selengkapnya).

Paramètre La deskripsi
batas (opsional) Hasil data per halaman
halaman (opsional) Permintaan halaman saat ini
curl --location --request GET 'https://urlkai.com/api/channels?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Une clé API est requise pour les demandes à traiter par le système. Une fois qu'un utilisateur s'enregistre, une clé API est générée automatiquement pour cet utilisateur. La clé API doit être envoyée avec chaque requête via le paramètre clé (voir l'exemple complet ci-dessous). Si la clé API n'est pas envoyée ou a expiré, une erreur se produit. Assurez-vous de garder votre clé secrète de l'API pour éviter tout abus.

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "channels": [
            {
                "id": 1,
                "name": "Channel 1",
                "description": "Description of channel 1",
                "color": "#000000",
                "starred": true
            },
            {
                "id": 2,
                "name": "Channel 2",
                "description": "Description of channel 2",
                "color": "#FF0000",
                "starred": false
            }
        ]
    }
}

Daftar Item Saluran

DAPAT https://urlkai.com/api/channel/:id?limit=1&page=1

Untuk mendapatkan item di saluran tertentu melalui API, Anda dapat menggunakan titik akhir ini. Anda juga dapat memfilter data (Lihat tabel untuk info selengkapnya).

Paramètre La deskripsi
batas (opsional) Hasil data per halaman
halaman (opsional) Permintaan halaman saat ini
curl --location --request GET 'https://urlkai.com/api/channel/:id?limit=1&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Une clé API est requise pour les demandes à traiter par le système. Une fois qu'un utilisateur s'enregistre, une clé API est générée automatiquement pour cet utilisateur. La clé API doit être envoyée avec chaque requête via le paramètre clé (voir l'exemple complet ci-dessous). Si la clé API n'est pas envoyée ou a expiré, une erreur se produit. Assurez-vous de garder votre clé secrète de l'API pour éviter tout abus.

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "items": [
            {
                "type": "links",
                "id": 1,
                "title": "My Sample Link",
                "preview": "https:\/\/google.com",
                "link": "https:\/\/urlkai.com\/google",
                "date": "2022-05-12"
            },
            {
                "type": "bio",
                "id": 1,
                "title": "My Sample Bio",
                "preview": "https:\/\/urlkai.com\/mybio",
                "link": "https:\/\/urlkai.com\/mybio",
                "date": "2022-06-01"
            }
        ]
    }
}

Créer une chaîne

TIANG https://urlkai.com/api/channel/add

Saluran dapat ditambahkan menggunakan titik akhir ini.

Paramètre La deskripsi
Nama (wajib) Nama saluran
deskripsi (opsional) Deskripsi saluran
warna (opsional) Warna lencana saluran (HEX)
dibintangi (opsional) Bintangi saluran atau tidak (benar atau salah)
curl --location --request POST 'https://urlkai.com/api/channel/add' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "name": "New Channel",
    "description": "my new channel",
    "color": "#000000",
    "starred": true
}'

Une clé API est requise pour les demandes à traiter par le système. Une fois qu'un utilisateur s'enregistre, une clé API est générée automatiquement pour cet utilisateur. La clé API doit être envoyée avec chaque requête via le paramètre clé (voir l'exemple complet ci-dessous). Si la clé API n'est pas envoyée ou a expiré, une erreur se produit. Assurez-vous de garder votre clé secrète de l'API pour éviter tout abus.

{
    "error": 0,
    "id": 3,
    "name": "New Channel",
    "description": "my new channel",
    "color": "#000000",
    "starred": true
}

Menetapkan item ke saluran

TIANG https://urlkai.com/api/channel/:channelid/assign/:type/:itemid

Item dapat ditetapkan ke saluran apa pun dengan mengirimkan permintaan dengan id saluran, jenis item (tautan, bio atau qr), dan id item.

Paramètre La deskripsi
:channelid (wajib) ID Saluran
:jenis (wajib) tautan atau bio atau QR
:itemid (wajib) Item ID
curl --location --request POST 'https://urlkai.com/api/channel/:channelid/assign/:type/:itemid' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Une clé API est requise pour les demandes à traiter par le système. Une fois qu'un utilisateur s'enregistre, une clé API est générée automatiquement pour cet utilisateur. La clé API doit être envoyée avec chaque requête via le paramètre clé (voir l'exemple complet ci-dessous). Si la clé API n'est pas envoyée ou a expiré, une erreur se produit. Assurez-vous de garder votre clé secrète de l'API pour éviter tout abus.

{
    "error": 0,
    "message": "Item successfully added to the channel."
}

Mettre à jour la chaîne

MELETAKKAN https://urlkai.com/api/channel/:id/update

Untuk memperbarui saluran, Anda perlu mengirim data yang valid dalam JSON melalui permintaan PUT. Data harus dikirim sebagai isi mentah permintaan Anda seperti yang ditunjukkan di bawah ini. Contoh di bawah ini menunjukkan semua parameter yang dapat Anda kirim tetapi Anda tidak diharuskan untuk mengirim semua (Lihat tabel untuk info selengkapnya).

Paramètre La deskripsi
Nama (opsional) Nama saluran
deskripsi (opsional) Deskripsi saluran
warna (opsional) Warna lencana saluran (HEX)
dibintangi (opsional) Bintangi saluran atau tidak (benar atau salah)
curl --location --request PUT 'https://urlkai.com/api/channel/:id/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "name": "Acme Corp",
    "description": "channel for items for Acme Corp",
    "color": "#FFFFFF",
    "starred": false
}'

Une clé API est requise pour les demandes à traiter par le système. Une fois qu'un utilisateur s'enregistre, une clé API est générée automatiquement pour cet utilisateur. La clé API doit être envoyée avec chaque requête via le paramètre clé (voir l'exemple complet ci-dessous). Si la clé API n'est pas envoyée ou a expiré, une erreur se produit. Assurez-vous de garder votre clé secrète de l'API pour éviter tout abus.

{
    "error": 0,
    "message": "Channel has been updated successfully."
}

Hapus Saluran

MENGHAPUS https://urlkai.com/api/channel/:id/delete

Untuk menghapus saluran, Anda perlu mengirim permintaan DELETE. Semua item juga tidak akan ditetapkan.

curl --location --request DELETE 'https://urlkai.com/api/channel/:id/delete' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Une clé API est requise pour les demandes à traiter par le système. Une fois qu'un utilisateur s'enregistre, une clé API est générée automatiquement pour cet utilisateur. La clé API doit être envoyée avec chaque requête via le paramètre clé (voir l'exemple complet ci-dessous). Si la clé API n'est pas envoyée ou a expiré, une erreur se produit. Assurez-vous de garder votre clé secrète de l'API pour éviter tout abus.

{
    "error": 0,
    "message": "Channel has been deleted successfully."
}

Daftar kode QR

DAPAT https://urlkai.com/api/qr?limit=2&page=1

Pour obtenir vos codes QR via l'API, vous pouvez utiliser ce point de terminaison. Vous pouvez également filtrer les données (voir le tableau pour plus d'informations).

Paramètre La deskripsi
batas (opsional) Hasil data per halaman
halaman (opsional) Permintaan halaman saat ini
curl --location --request GET 'https://urlkai.com/api/qr?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Une clé API est requise pour les demandes à traiter par le système. Une fois qu'un utilisateur s'enregistre, une clé API est générée automatiquement pour cet utilisateur. La clé API doit être envoyée avec chaque requête via le paramètre clé (voir l'exemple complet ci-dessous). Si la clé API n'est pas envoyée ou a expiré, une erreur se produit. Assurez-vous de garder votre clé secrète de l'API pour éviter tout abus.

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "qrs": [
            {
                "id": 2,
                "link": "https:\/\/urlkai.com\/qr\/a2d5e",
                "scans": 0,
                "name": "Google",
                "date": "2020-11-10 18:01:43"
            },
            {
                "id": 1,
                "link": "https:\/\/urlkai.com\/qr\/b9edfe",
                "scans": 5,
                "name": "Google Canada",
                "date": "2020-11-10 18:00:25"
            }
        ]
    }
}

Obtenez un seul code QR

DAPAT https://urlkai.com/api/qr/:id

Pour obtenir les détails d'un seul code QR via l'API, vous pouvez utiliser ce point de terminaison.

curl --location --request GET 'https://urlkai.com/api/qr/:id' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Une clé API est requise pour les demandes à traiter par le système. Une fois qu'un utilisateur s'enregistre, une clé API est générée automatiquement pour cet utilisateur. La clé API doit être envoyée avec chaque requête via le paramètre clé (voir l'exemple complet ci-dessous). Si la clé API n'est pas envoyée ou a expiré, une erreur se produit. Assurez-vous de garder votre clé secrète de l'API pour éviter tout abus.

{
    "error": 0,
    "details": {
        "id": 1,
        "link": "https:\/\/urlkai.com\/qr\/b9edfe",
        "scans": 5,
        "name": "Google Canada",
        "date": "2020-11-10 18:00:25"
    },
    "data": {
        "clicks": 1,
        "uniqueClicks": 1,
        "topCountries": {
            "Unknown": "1"
        },
        "topReferrers": {
            "Direct, email and other": "1"
        },
        "topBrowsers": {
            "Chrome": "1"
        },
        "topOs": {
            "Windows 10": "1"
        },
        "socialCount": {
            "facebook": 0,
            "twitter": 0,
            "instagram": 0
        }
    }
}

Créer un code QR

TIANG https://urlkai.com/api/qr/add

Untuk membuat Kode QR, Anda perlu mengirim data yang valid dalam JSON melalui permintaan POST. Data harus dikirim sebagai isi mentah permintaan Anda seperti yang ditunjukkan di bawah ini. Contoh di bawah ini menunjukkan semua parameter yang dapat Anda kirim tetapi Anda tidak diharuskan untuk mengirim semua (Lihat tabel untuk info selengkapnya).

Paramètre La deskripsi
jenis (wajib) teks | vcard | Tautan | email | Telepon | SMS | Wi-Fi
data (wajib) Data yang akan disematkan di dalam kode QR. Data dapat berupa string atau array tergantung pada jenisnya
latar (opsional) Warna RGB misalnya rgb (255,255,255)
Depan (opsional) Warna RGB misalnya rgb (0,0,0)
logo (opsional) Jalur ke logo baik png atau jpg
Nama (opsional) Nama Kode QR
curl --location --request POST 'https://urlkai.com/api/qr/add' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "type": "link",
    "data": "https:\/\/google.com",
    "background": "rgb(255,255,255)",
    "foreground": "rgb(0,0,0)",
    "logo": "https:\/\/site.com\/logo.png",
    "name": "QR Code API"
}'

Une clé API est requise pour les demandes à traiter par le système. Une fois qu'un utilisateur s'enregistre, une clé API est générée automatiquement pour cet utilisateur. La clé API doit être envoyée avec chaque requête via le paramètre clé (voir l'exemple complet ci-dessous). Si la clé API n'est pas envoyée ou a expiré, une erreur se produit. Assurez-vous de garder votre clé secrète de l'API pour éviter tout abus.

{
    "error": 0,
    "id": 3,
    "link": "https:\/\/urlkai.com\/qr\/a58f79"
}

Perbarui Kode QR

MELETAKKAN https://urlkai.com/api/qr/:id/update

Pour mettre à jour un QR Code, vous devez envoyer une donnée valide au format JSON via une requête PUT. Les données doivent être envoyées en tant que corps brut de votre demande, comme indiqué ci-dessous. L'exemple ci-dessous montre tous les paramètres que vous pouvez envoyer mais vous n'êtes pas obligé de tous les envoyer (voir le tableau pour plus d'informations).

Paramètre La deskripsi
data (wajib) Data yang akan disematkan di dalam kode QR. Data dapat berupa string atau array tergantung pada jenisnya
latar (opsional) Warna RGB misalnya rgb (255,255,255)
Depan (opsional) Warna RGB misalnya rgb (0,0,0)
logo (opsional) Jalur ke logo baik png atau jpg
curl --location --request PUT 'https://urlkai.com/api/qr/:id/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "type": "link",
    "data": "https:\/\/google.com",
    "background": "rgb(255,255,255)",
    "foreground": "rgb(0,0,0)",
    "logo": "https:\/\/site.com\/logo.png"
}'

Une clé API est requise pour les demandes à traiter par le système. Une fois qu'un utilisateur s'enregistre, une clé API est générée automatiquement pour cet utilisateur. La clé API doit être envoyée avec chaque requête via le paramètre clé (voir l'exemple complet ci-dessous). Si la clé API n'est pas envoyée ou a expiré, une erreur se produit. Assurez-vous de garder votre clé secrète de l'API pour éviter tout abus.

{
    "error": 0,
    "message": "QR has been updated successfully."
}

Supprimer un kode QR

MENGHAPUS https://urlkai.com/api/qr/:id/delete

Pour supprimer un code QR, vous devez envoyer une demande DELETE.

curl --location --request DELETE 'https://urlkai.com/api/qr/:id/delete' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Une clé API est requise pour les demandes à traiter par le système. Une fois qu'un utilisateur s'enregistre, une clé API est générée automatiquement pour cet utilisateur. La clé API doit être envoyée avec chaque requête via le paramètre clé (voir l'exemple complet ci-dessous). Si la clé API n'est pas envoyée ou a expiré, une erreur se produit. Assurez-vous de garder votre clé secrète de l'API pour éviter tout abus.

{
    "error": 0,
    "message": "QR Code has been deleted successfully."
}

Obtenir un compte

DAPAT https://urlkai.com/api/account

Pour obtenir des informations sur le compte, vous pouvez envoyer une demande à ce point de terminaison et il renverra des données sur le compte.

curl --location --request GET 'https://urlkai.com/api/account' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Une clé API est requise pour les demandes à traiter par le système. Une fois qu'un utilisateur s'enregistre, une clé API est générée automatiquement pour cet utilisateur. La clé API doit être envoyée avec chaque requête via le paramètre clé (voir l'exemple complet ci-dessous). Si la clé API n'est pas envoyée ou a expiré, une erreur se produit. Assurez-vous de garder votre clé secrète de l'API pour éviter tout abus.

{
    "error": 0,
    "data": {
        "id": 1,
        "email": "[email protected]",
        "username": "sampleuser",
        "avatar": "https:\/\/domain.com\/content\/avatar.png",
        "status": "pro",
        "expires": "2022-11-15 15:00:00",
        "registered": "2020-11-10 18:01:43"
    }
}

Compte mis à jour

MELETAKKAN https://urlkai.com/api/account/update

Pour mettre à jour les informations sur le compte, vous pouvez envoyer une demande à ce point de terminaison et il mettra à jour les données sur le compte.

curl --location --request PUT 'https://urlkai.com/api/account/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "email": "[email protected]",
    "password": "NewPassword1"
}'

Une clé API est requise pour les demandes à traiter par le système. Une fois qu'un utilisateur s'enregistre, une clé API est générée automatiquement pour cet utilisateur. La clé API doit être envoyée avec chaque requête via le paramètre clé (voir l'exemple complet ci-dessous). Si la clé API n'est pas envoyée ou a expiré, une erreur se produit. Assurez-vous de garder votre clé secrète de l'API pour éviter tout abus.

{
    "error": 0,
    "message": "Account has been successfully updated."
}

Domaines de marque

Daftar Domain Bermerek

DAPAT https://urlkai.com/api/domains?limit=2&page=1

Untuk mendapatkan domain bermerek Anda melalui API, Anda dapat menggunakan endpoint ini. Anda juga dapat memfilter data (Lihat tabel untuk info selengkapnya).

Paramètre La deskripsi
batas (opsional) Hasil data per halaman
halaman (opsional) Permintaan halaman saat ini
curl --location --request GET 'https://urlkai.com/api/domains?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Une clé API est requise pour les demandes à traiter par le système. Une fois qu'un utilisateur s'enregistre, une clé API est générée automatiquement pour cet utilisateur. La clé API doit être envoyée avec chaque requête via le paramètre clé (voir l'exemple complet ci-dessous). Si la clé API n'est pas envoyée ou a expiré, une erreur se produit. Assurez-vous de garder votre clé secrète de l'API pour éviter tout abus.

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "domains": [
            {
                "id": 1,
                "domain": "https:\/\/domain1.com",
                "redirectroot": "https:\/\/rootdomain.com",
                "redirect404": "https:\/\/rootdomain.com\/404"
            },
            {
                "id": 2,
                "domain": "https:\/\/domain2.com",
                "redirectroot": "https:\/\/rootdomain2.com",
                "redirect404": "https:\/\/rootdomain2.com\/404"
            }
        ]
    }
}

Membuat Domain Bermerek

TIANG https://urlkai.com/api/domain/add

Domain dapat ditambahkan menggunakan titik akhir ini. Pastikan domain diarahkan dengan benar ke server kami.

Paramètre La deskripsi
Domain (wajib) Domain bermerek termasuk http atau https
pengalihan root (opsional) Pengalihan root saat seseorang mengunjungi domain Anda
pengalihan404 (opsional) Pengalihan 404 kustom
curl --location --request POST 'https://urlkai.com/api/domain/add' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "domain": "https:\/\/domain1.com",
    "redirectroot": "https:\/\/rootdomain.com",
    "redirect404": "https:\/\/rootdomain.com\/404"
}'

Une clé API est requise pour les demandes à traiter par le système. Une fois qu'un utilisateur s'enregistre, une clé API est générée automatiquement pour cet utilisateur. La clé API doit être envoyée avec chaque requête via le paramètre clé (voir l'exemple complet ci-dessous). Si la clé API n'est pas envoyée ou a expiré, une erreur se produit. Assurez-vous de garder votre clé secrète de l'API pour éviter tout abus.

{
    "error": 0,
    "id": 1
}

Mettre à jour le domaine

MELETAKKAN https://urlkai.com/api/domain/:id/update

Untuk memperbarui domain bermerek, Anda harus mengirim data yang valid dalam JSON melalui permintaan PUT. Data harus dikirim sebagai isi mentah permintaan Anda seperti yang ditunjukkan di bawah ini. Contoh di bawah ini menunjukkan semua parameter yang dapat Anda kirim tetapi Anda tidak diharuskan untuk mengirim semua (Lihat tabel untuk info selengkapnya).

Paramètre La deskripsi
pengalihan root (opsional) Pengalihan root saat seseorang mengunjungi domain Anda
pengalihan404 (opsional) Pengalihan 404 kustom
curl --location --request PUT 'https://urlkai.com/api/domain/:id/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "redirectroot": "https:\/\/rootdomain-new.com",
    "redirect404": "https:\/\/rootdomain-new.com\/404"
}'

Une clé API est requise pour les demandes à traiter par le système. Une fois qu'un utilisateur s'enregistre, une clé API est générée automatiquement pour cet utilisateur. La clé API doit être envoyée avec chaque requête via le paramètre clé (voir l'exemple complet ci-dessous). Si la clé API n'est pas envoyée ou a expiré, une erreur se produit. Assurez-vous de garder votre clé secrète de l'API pour éviter tout abus.

{
    "error": 0,
    "message": "Domain has been updated successfully."
}

Hapus Domain

MENGHAPUS https://urlkai.com/api/domain/:id/delete

Untuk menghapus domain, Anda perlu mengirim permintaan DELETE.

curl --location --request DELETE 'https://urlkai.com/api/domain/:id/delete' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Une clé API est requise pour les demandes à traiter par le système. Une fois qu'un utilisateur s'enregistre, une clé API est générée automatiquement pour cet utilisateur. La clé API doit être envoyée avec chaque requête via le paramètre clé (voir l'exemple complet ci-dessous). Si la clé API n'est pas envoyée ou a expiré, une erreur se produit. Assurez-vous de garder votre clé secrète de l'API pour éviter tout abus.

{
    "error": 0,
    "message": "Domain has been deleted successfully."
}

Daftar File

DAPAT https://urlkai.com/api/files?limit=2&page=1

Dapatkan semua file Anda. Anda juga dapat mencari berdasarkan nama.

Paramètre La deskripsi
Nama (opsional) Menelusuri file berdasarkan nama
batas (opsional) Hasil data per halaman
halaman (opsional) Permintaan halaman saat ini
curl --location --request GET 'https://urlkai.com/api/files?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Une clé API est requise pour les demandes à traiter par le système. Une fois qu'un utilisateur s'enregistre, une clé API est générée automatiquement pour cet utilisateur. La clé API doit être envoyée avec chaque requête via le paramètre clé (voir l'exemple complet ci-dessous). Si la clé API n'est pas envoyée ou a expiré, une erreur se produit. Assurez-vous de garder votre clé secrète de l'API pour éviter tout abus.

{
    "error": 0,
    "result": 3,
    "perpage": 15,
    "currentpage": 1,
    "nextpage": null,
    "maxpage": 1,
    "list": [
        {
            "id": 1,
            "name": "My Photo",
            "downloads": 10,
            "shorturl": "https:\/\/urlkai.com\/lISKN",
            "date": "2022-08-09 17:00:00"
        },
        {
            "id": 2,
            "name": "My Documents",
            "downloads": 15,
            "shorturl": "https:\/\/urlkai.com\/efJeP",
            "date": "2022-08-10 17:01:00"
        },
        {
            "id": 3,
            "name": "My Files",
            "downloads": 5,
            "shorturl": "https:\/\/urlkai.com\/RnbXD",
            "date": "2022-08-11 19:01:00"
        }
    ]
}

Mengunggah file

TIANG https://urlkai.com/api/files/upload/:filename?name=My+File

Unggah file dengan mengirimkan data biner sebagai isi postingan. Anda perlu mengirim nama file termasuk ekstensi, bukan :filename di url (misalnya brandkit.zip). Anda dapat mengatur opsi dengan mengirimkan parameter berikut.

Paramètre La deskripsi
Nama (opsional) Nama file
adat (opsional) Alias kustom alih-alih alias acak.
Domain (opsional) Domain Kustom
kata sandi (opsional) Perlindungan kata sandi
Kedaluwarsa (opsional) Kedaluwarsa untuk contoh unduhan 2021-09-28
maxunduhan (opsional) Jumlah maksimum unduhan
curl --location --request POST 'https://urlkai.com/api/files/upload/:filename?name=My+File' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '"BINARY DATA"'

Une clé API est requise pour les demandes à traiter par le système. Une fois qu'un utilisateur s'enregistre, une clé API est générée automatiquement pour cet utilisateur. La clé API doit être envoyée avec chaque requête via le paramètre clé (voir l'exemple complet ci-dessous). Si la clé API n'est pas envoyée ou a expiré, une erreur se produit. Assurez-vous de garder votre clé secrète de l'API pour éviter tout abus.

{
    "error": 0,
    "id": 1,
    "shorturl": "https:\/\/urlkai.com\/CmOwN"
}

Daftar Piksel

DAPAT https://urlkai.com/api/pixels?limit=2&page=1

Untuk mendapatkan kode piksel melalui API, Anda dapat menggunakan endpoint ini. Anda juga dapat memfilter data (Lihat tabel untuk info selengkapnya).

Paramètre La deskripsi
batas (opsional) Hasil data per halaman
halaman (opsional) Permintaan halaman saat ini
curl --location --request GET 'https://urlkai.com/api/pixels?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Une clé API est requise pour les demandes à traiter par le système. Une fois qu'un utilisateur s'enregistre, une clé API est générée automatiquement pour cet utilisateur. La clé API doit être envoyée avec chaque requête via le paramètre clé (voir l'exemple complet ci-dessous). Si la clé API n'est pas envoyée ou a expiré, une erreur se produit. Assurez-vous de garder votre clé secrète de l'API pour éviter tout abus.

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "pixels": [
            {
                "id": 1,
                "type": "gtmpixel",
                "name": "GTM Pixel",
                "tag": "GA-123456789",
                "date": "2020-11-10 18:00:00"
            },
            {
                "id": 2,
                "type": "twitterpixel",
                "name": "Twitter Pixel",
                "tag": "1234567",
                "date": "2020-11-10 18:10:00"
            }
        ]
    }
}

Membuat piksel

TIANG https://urlkai.com/api/pixel/add

Piksel dapat dibuat menggunakan titik akhir ini. Anda perlu mengirim jenis piksel dan tag.

Paramètre La deskripsi
jenis (wajib) gtmpixel | gapixel | FBPIXEL | AdwordsPixel | LinkedInInpixel | Piksel Twitter | AdrollPixel | Quorapixel | Pinterest | Bing | Snapchat | Reddit | TikTok
Nama (wajib) Nama khusus untuk piksel Anda
Tag (wajib) Tag untuk piksel
curl --location --request POST 'https://urlkai.com/api/pixel/add' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "type": "gtmpixel",
    "name": "My GTM",
    "tag": "GTM-ABCDE"
}'

Une clé API est requise pour les demandes à traiter par le système. Une fois qu'un utilisateur s'enregistre, une clé API est générée automatiquement pour cet utilisateur. La clé API doit être envoyée avec chaque requête via le paramètre clé (voir l'exemple complet ci-dessous). Si la clé API n'est pas envoyée ou a expiré, une erreur se produit. Assurez-vous de garder votre clé secrète de l'API pour éviter tout abus.

{
    "error": 0,
    "id": 1
}

Mettre à jour le pixel

MELETAKKAN https://urlkai.com/api/pixel/:id/update

Untuk memperbarui piksel, Anda perlu mengirim data yang valid dalam JSON melalui permintaan PUT. Data harus dikirim sebagai isi mentah permintaan Anda seperti yang ditunjukkan di bawah ini. Contoh di bawah ini menunjukkan semua parameter yang dapat Anda kirim tetapi Anda tidak diharuskan untuk mengirim semua (Lihat tabel untuk info selengkapnya).

Paramètre La deskripsi
Nama (opsional) Nama khusus untuk piksel Anda
Tag (wajib) Tag untuk piksel
curl --location --request PUT 'https://urlkai.com/api/pixel/:id/update' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \
--data-raw '{
    "name": "My GTM",
    "tag": "GTM-ABCDE"
}'

Une clé API est requise pour les demandes à traiter par le système. Une fois qu'un utilisateur s'enregistre, une clé API est générée automatiquement pour cet utilisateur. La clé API doit être envoyée avec chaque requête via le paramètre clé (voir l'exemple complet ci-dessous). Si la clé API n'est pas envoyée ou a expiré, une erreur se produit. Assurez-vous de garder votre clé secrète de l'API pour éviter tout abus.

{
    "error": 0,
    "message": "Pixel has been updated successfully."
}

Hapus Piksel

MENGHAPUS https://urlkai.com/api/pixel/:id/delete

Untuk menghapus piksel, Anda perlu mengirim permintaan HAPUS.

curl --location --request DELETE 'https://urlkai.com/api/pixel/:id/delete' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Une clé API est requise pour les demandes à traiter par le système. Une fois qu'un utilisateur s'enregistre, une clé API est générée automatiquement pour cet utilisateur. La clé API doit être envoyée avec chaque requête via le paramètre clé (voir l'exemple complet ci-dessous). Si la clé API n'est pas envoyée ou a expiré, une erreur se produit. Assurez-vous de garder votre clé secrète de l'API pour éviter tout abus.

{
    "error": 0,
    "message": "Pixel has been deleted successfully."
}

Splash personnalisé

Daftar Splash Kustom

DAPAT https://urlkai.com/api/splash?limit=2&page=1

To get Splash Pages via the API, you can use this endpoint. You can also filter data (See table for more info).

Paramètre La deskripsi
batas (opsional) Hasil data per halaman
halaman (opsional) Permintaan halaman saat ini
curl --location --request GET 'https://urlkai.com/api/splash?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Une clé API est requise pour les demandes à traiter par le système. Une fois qu'un utilisateur s'enregistre, une clé API est générée automatiquement pour cet utilisateur. La clé API doit être envoyée avec chaque requête via le paramètre clé (voir l'exemple complet ci-dessous). Si la clé API n'est pas envoyée ou a expiré, une erreur se produit. Assurez-vous de garder votre clé secrète de l'API pour éviter tout abus.

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "splash": [
            {
                "id": 1,
                "name": "Product 1 Promo",
                "date": "2020-11-10 18:00:00"
            },
            {
                "id": 2,
                "name": "Product 2 Promo",
                "date": "2020-11-10 18:10:00"
            }
        ]
    }
}

Superposisi CTA

Daftar Overlay CTA

DAPAT https://urlkai.com/api/overlay?limit=2&page=1

Untuk mendapatkan overlay cta melalui API, Anda dapat menggunakan titik akhir ini. Anda juga dapat memfilter data (Lihat tabel untuk info selengkapnya).

Paramètre La deskripsi
batas (opsional) Hasil data per halaman
halaman (opsional) Permintaan halaman saat ini
curl --location --request GET 'https://urlkai.com/api/overlay?limit=2&page=1' \
--header 'Authorization: Bearer YOURAPIKEY' \
--header 'Content-Type: application/json' \

Une clé API est requise pour les demandes à traiter par le système. Une fois qu'un utilisateur s'enregistre, une clé API est générée automatiquement pour cet utilisateur. La clé API doit être envoyée avec chaque requête via le paramètre clé (voir l'exemple complet ci-dessous). Si la clé API n'est pas envoyée ou a expiré, une erreur se produit. Assurez-vous de garder votre clé secrète de l'API pour éviter tout abus.

{
    "error": "0",
    "data": {
        "result": 2,
        "perpage": 2,
        "currentpage": 1,
        "nextpage": 1,
        "maxpage": 1,
        "cta": [
            {
                "id": 1,
                "type": "message",
                "name": "Product 1 Promo",
                "date": "2020-11-10 18:00:00"
            },
            {
                "id": 2,
                "type": "contact",
                "name": "Contact Page",
                "date": "2020-11-10 18:10:00"
            }
        ]
    }
}